<?php
/**
 * VK Blocks - Custom Css Extension
 *
 * @package vk-blocks
 */

/**
 * Render Custom Css Extension css
 *
 * @see https://github.com/WordPress/gutenberg/blob/3358251ae150e33dd6c0e0fb15be110cca1b5c59/lib/block-supports/layout.php#L294
 *
 * @param string $block_content block_content.
 * @param array  $block block.
 * @return string
 */
function vk_blocks_custom_css_extension( $block_content, $block ) {
	if ( ! empty( $block['attrs']['vkbCustomCss'] ) ) {
		$css = $block['attrs']['vkbCustomCss'];
		// Uniqueクラスを生成
		$custom_css_class = wp_unique_id( 'vk_custom_css_' );
		// selector文字列をUniqueクラスに変換
		$css = preg_replace( '/selector/', '.' . $custom_css_class, $css );
		$css = vk_blocks_minify_css( $css );
		// vk_custom_css文字列をUniqueクラスに変換
		$content = preg_replace( '/vk_custom_css/', $custom_css_class, $block_content );
		if ( ! empty( $css ) ) {
			return '<style>' . $css . '</style>' . $content;
		}
		return $block_content;
	}
	return $block_content;
}
add_filter( 'render_block', 'vk_blocks_custom_css_extension', 10, 2 );

/**
 * 各ブロックにvkbCustomCssのattributesを追加する
 *
 * @param string $settings settings.
 * @param array  $metadata metadata.
 * @return string
 */
function vk_blocks_add_custom_css_attributes( $settings, $metadata ) {
	if ( preg_match( '/core|vk-blocks/', $metadata['name'] ) ) {
		$attributes = array();
		if ( ! empty( $settings['attributes'] ) ) {
			$attributes = $settings['attributes'];
		}
		$add_attributes = array(
			'vkbCustomCss' => array(
				'type'    => 'string',
				'default' => '',
			),
		);

		$settings['attributes'] = array_merge(
			$attributes,
			$add_attributes
		);
	}
	return $settings;
}
add_filter( 'block_type_metadata_settings', 'vk_blocks_add_custom_css_attributes', 10, 2 );
